Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(757)

Unified Diff: chrome/browser/ui/webui/ntp/new_tab_page_handler.h

Issue 10911196: Support for ntp promo bubble. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: allow BR in parseHtmlSubset Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/resources/ntp4/new_tab.js ('k') | chrome/browser/ui/webui/ntp/new_tab_page_handler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/webui/ntp/new_tab_page_handler.h
===================================================================
--- chrome/browser/ui/webui/ntp/new_tab_page_handler.h (revision 155564)
+++ chrome/browser/ui/webui/ntp/new_tab_page_handler.h (working copy)
@@ -17,30 +17,37 @@
class NewTabPageHandler : public content::WebUIMessageHandler {
public:
NewTabPageHandler();
+
+ // Register NTP per-profile preferences.
+ static void RegisterUserPrefs(PrefService* prefs);
+
+ // Register NTP profile-independent preferences.
+ static void RegisterPrefs(PrefService* prefs);
+
+ // Registers values (strings etc.) for the page.
+ static void GetLocalizedValues(Profile* profile, DictionaryValue* values);
+
+ private:
virtual ~NewTabPageHandler();
// WebUIMessageHandler implementation.
virtual void RegisterMessages() OVERRIDE;
- // Callback for "closeNotificationPromo".
- void HandleCloseNotificationPromo(const ListValue* args);
+ // Callback for "notificationPromoClosed". No arguments.
+ void HandleNotificationPromoClosed(const ListValue* args);
- // Callback for "notificationPromoViewed".
+ // Callback for "notificationPromoViewed". No arguments.
void HandleNotificationPromoViewed(const ListValue* args);
+ // Callback for "bubblePromoClosed". No arguments.
+ void HandleBubblePromoClosed(const ListValue* args);
+
+ // Callback for "bubblePromoViewed". No arguments.
+ void HandleBubblePromoViewed(const ListValue* args);
+
// Callback for "pageSelected".
void HandlePageSelected(const ListValue* args);
- // Register NTP per-profile preferences.
- static void RegisterUserPrefs(PrefService* prefs);
-
- // Register NTP profile-independent preferences.
- static void RegisterPrefs(PrefService* prefs);
-
- // Registers values (strings etc.) for the page.
- static void GetLocalizedValues(Profile* profile, DictionaryValue* values);
-
- private:
// Tracks the number of times the user has switches pages (for UMA).
size_t page_switch_count_;
« no previous file with comments | « chrome/browser/resources/ntp4/new_tab.js ('k') | chrome/browser/ui/webui/ntp/new_tab_page_handler.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698